c**********************************************************************
c   pi.f - compute pi by integrating f(x) = 4/(1 + x**2)     
c     
c   Each node: 
c    1) receives the number of rectangles used in the approximation.
c    2) calculates the areas of it's rectangles.
c    3) Synchronizes for a global summation.
c   Node 0 prints the result.
c
c  Variables:
c
c    pi  the calculated result
c    n   number of points of integration.  
c    x           midpoint of each rectangle's interval
c    f           function to integrate
c    sum,pi      area of rectangles
c    tmp         temporary scratch space for global summation
c    i           do loop index
c****************************************************************************
      program main

      double precision  PI25DT
      parameter        (PI25DT = 3.141592653589793238462643d0)

      double precision  pi, h, sum, x, f, a
      double precision stime, etime, tstart(2)
      integer*2 tzone(2)
      integer n, myid, numprocs, i, rc
c                                 function to integrate
      f(a) = 4.d0 / (1.d0 + a*a)

      n=100000000
c                                 calculate the interval size
      h = 1.0d0/n

      call cgettimeofday(tstart,tzone)

      stime =  tstart(1) + tstart(2)/(1000*1000)

      sum  = 0.0d0
      do 20 i = 1, n 
         x = h * (dble(i) - 0.5d0)
         sum = sum + f(x)
 20   continue
      pi = h * sum

      call cgettimeofday(tstart,tzone)

      etime =  tstart(1) + tstart(2)/(1000*1000)

      write(6, 97) pi, abs(pi - PI25DT)
 97   format('  pi is approximately: ', F18.16,
     +          '  Error is: ', F18.16)
      write(6, 98) etime-stime
 98   format('  Runtime: ', F18.16)
      

      stop
      end




