#!/bin/bash
#set -x   # Verbose output
set -e

# Script written by Wim R.Cardoen on 01/12/2018

# Set the PATH of the GSL Directory
export GSL_DIR=$HOME/Ex5/pkg/gsl/2.4

myhelp ()
{
  echo "    Syntax: CMD <arg> "
  echo "      arg: 'install' / '-i' -> install integ library"
  echo "           'clean'   / '-c' -> clean up "
  echo "           'help'    / '-h' -> ask for help"
  echo "    Make sure that GSL_DIR is set to a valid directory"
  echo "      GSL_DIR:'$GSL_DIR'"
  echo ""
}

# Cleanup Function
# Remove object files, static & dynamic libraries
cleanup ()
{
  rm -rf src/*.o
  rm -rf lib/{*.a,*.so}  
}

# Function which builds STATIC & DYNAMIC libraries
buildlib ()
{
  echo ""
  echo "  Building STATIC Library"
  cd src
  gcc -c -I$GSL_DIR/include -I../include mc.c
  gcc -c -I../include trap.c

  cd ../lib
  ar -rcv libinteg.a ../src/{mc.o,trap.o} 
  cd ..

  echo ""
  echo "  Building DYNAMIC Library"
  cd src; rm -rf *.o

  gcc -c -fPIC -I$GSL_DIR/include -I../include mc.c
  gcc -c -fPIC -I../include trap.c

  cd ../lib
  gcc -shared -fPIC -o libinteg.so ../src/{mc.o,trap.o}

  # Check:
  echo ""
  echo "  Check presence of libraries in lib/"
  for i in `ls ./`; do
      echo "    $i"
  done

  cd ..
} 


if [ $# == 1 ]; then
   if [ $1 == "-i" ] || [ $1 == "install" ]; then

        # Check whether the GSL Library is installed
        if [ ! -d "$GSL_DIR" ]; then
           echo "  Installation ERROR:"
           echo "    The GSL dir. $GSL_DIR does NOT exist or can NOT be reached "
           exit 
        fi   
        echo "  GSL library that will be used:"
        echo "    '$GSL_DIR'"

        # Thorough clean up
        cleanup
        
        # Build up lib
        buildlib

   elif [ "$1" == "-h" ] || [ "$1" == "help" ]; then
        myhelp
        exit
   elif [ "$1" == "-c" ] || [ "$1" == "clean" ]; then
        cleanup
        exit
   else
        echo " "
        echo "  ERROR: Unknown keyword:'$1' "
        myhelp
        exit
   fi

else
   echo " "
   myhelp
   exit
fi
