#!/bin/bash
# set -x (Verbosity)
set -e

# Script written by Wim R.Cardoen on 01/12/2018

# Set the PATHS of the GSL & INTEG Directories
export GSL_DIR=$HOME/Ex5/pkg/gsl/2.4
export INTEG_DIR=../integ

cleanup ()
{
  rm -rf *.o
  rm -rf main_d1 main_d2 main_s1 main_s2
}

myhelp ()
{
  echo "    Syntax: CMD <arg> "
  echo "      arg: 'install' / '-i' -> create executables"
  echo "           'clean'   / '-c' -> clean up "
  echo "           'help'    / '-h' -> ask for help"
  echo "    Make sure that GSL_DIR & INTEG_DIR are set to a valid directory"
  echo "      GSL_DIR  :'$GSL_DIR'"
  echo "      INTEG_DIR:'$INTEG_DIR'"
  echo ""
} 

buildexe()
{ 
  echo ""
  echo "  Compile Source Code:"
  gcc -c -I. functions.c
  gcc -c -I. -I$INTEG_DIR/include main.c
  echo  ""

  echo "  Create Executables:"
  echo "    main_d1:" 
  gcc -o main_d1 main.o functions.o -L$GSL_DIR/lib -lgslcblas -lgsl -lm -L$INTEG_DIR/lib -linteg

  echo "    main_d2:" 
  gcc -o main_d2 main.o functions.o -Wl,-rpath=$GSL_DIR/lib -L$GSL_DIR/lib -lgslcblas -lgsl -Wl,-rpath=$INTEG_DIR/lib -L$INTEG_DIR/lib -linteg -lm

  echo "    main_s1:"  
  gcc -o main_s1 main.o functions.o -Wl,-rpath=$GSL_DIR/lib -L$GSL_DIR/lib -lgslcblas -lgsl -L$INTEG_DIR/lib $INTEG_DIR/lib/libinteg.a -lm 

  echo "    main_s2:"
  gcc -static -o main_s2 main.o functions.o -L$INTEG_DIR/lib $INTEG_DIR/lib/libinteg.a -L$GSL_DIR/lib $GSL_DIR/lib/libgsl.a $GSL_DIR/lib/libgslcblas.a -lm
  echo ""
}


if [ $# == 1 ]; then
   if [ $1 == "-i" ] || [ $1 == "install" ]; then

        # Check whether the GSL Library is installed
        if [ ! -d "$GSL_DIR" ]; then
           echo "  Installation ERROR:"
           echo "    The GSL dir. $GSL_DIR does NOT exist or can NOT be reached "
           exit
        fi

        # Check whether the Integral Library is installed
        if [ ! -d "$INTEG_DIR" ]; then
           echo "  Installation ERROR:"
           echo "    The INTEG dir. $INTEG_DIR does NOT exist or can NOT be reached "
           exit
        fi

        echo "  GSL library that will be used:"
        echo "    '$GSL_DIR'"

        echo "  Integral library that will be used:"
        echo "    '$INTEG_DIR'"


        # Thorough clean up
        cleanup

        # Build up lib
        buildexe

   elif [ "$1" == "-h" ] || [ "$1" == "help" ]; then
        myhelp
        exit
   elif [ "$1" == "-c" ] || [ "$1" == "clean" ]; then
        cleanup
        exit
   else
        echo " "
        echo "  ERROR: Unknown keyword:'$1' "
        myhelp
        exit
   fi
else
   echo " "
   myhelp
   exit

fi
